import axios from 'axios';
import AdminLayout from './layout';
import { API_URL, currencyFormatter } from '@pos/base';
import { useEffect, useState } from 'react';
import { Card, Col, DatePicker, Row, Table, Typography } from 'antd';
import dayjs from 'dayjs';
import { filter } from 'lodash';

export default function Admin() {
  const [dataItem, setDataItem] = useState<any[]>([]);
  const [dataItemMaster, setDataItemMaster] = useState<any[]>([]);

  const [loadingDataItem, setLoadingDataItem] = useState<boolean>(false);
  const [loadingDataItemMaster, setLoadingDataItemMaster] = useState<boolean>(false);
  const [filterDate, setFilerDate] = useState(dayjs());

  async function getDataItem(params: any) {
    setLoadingDataItem(true);
    await axios
      .get(API_URL.REPORT_SUMMARY_INCOME_ITEM, { params: params })
      .then((resp) => {
        const data = resp.data.data;
        setDataItem(data);
      })
      .catch((err) => {
        console.log(err);
      })
      .finally(() => {
        setLoadingDataItem(false);
      });
  }

  async function getDataItemMaster(params: any) {
    setLoadingDataItemMaster(true);
    await axios
      .get(API_URL.REPORT_SUMMARY_INCOME_ITEM_MASTER, { params: params })
      .then((resp) => {
        const data = resp.data.data;
        setDataItemMaster(data);
      })
      .catch((err) => {
        console.log(err);
      })
      .finally(() => {
        setLoadingDataItemMaster(false);
      });
  }

  function handleGetDate(date: any) {
    getDataItem({ date });
    getDataItemMaster({ date });
  }

  useEffect(() => {
    if (filterDate) {
      handleGetDate(filterDate.format('DD-MM-YYYY'));
    }
  }, [filterDate]);

  return (
    <AdminLayout>
      <Row>
        <Col xl={8} lg={8} md={12} span={24}>
          <DatePicker value={filterDate} style={{ width: '100%' }} format={'DD-MM-YYYY'} onChange={setFilerDate} />
        </Col>
      </Row>
      <div style={{ marginBottom: 20 }}></div>

      <Card title={'PENDAPATAN PER ITEM'}>
        <Table
          bordered
          size="small"
          dataSource={dataItem}
          pagination={false}
          loading={loadingDataItem}
          scroll={{ x: 'max-width', y: 350 }}
          columns={[
            { dataIndex: 'main__payment_date', title: 'Date', width: 100 },
            { dataIndex: 'item_owner', title: 'Ownership', width: 100 },
            { dataIndex: 'tr_item__item_name', title: 'Item', width: 150 },
            { dataIndex: 'tr_item__qty', title: 'PAX', width: 70 },
            {
              dataIndex: 'tr_item__total_net_price',
              title: 'Revenue',
              width: 150,
              render: (value) => currencyFormatter({ value }),
            },
          ]}
        />
      </Card>
      <div style={{ marginBottom: 20 }}></div>
      <Card title="PENDAPATAN PER ITEM MASTER">
        <Table
          bordered
          size="small"
          dataSource={dataItemMaster}
          pagination={false}
          loading={loadingDataItemMaster}
          scroll={{ x: 'max-width', y: 350 }}
          columns={[
            { dataIndex: 'main__payment_date', title: 'Date', width: 100 },
            { dataIndex: 'item_owner', title: 'Ownership', width: 100 },
            {
              dataIndex: 'tr_item_bundling__item_name',
              title: 'Item Bundling',
              width: 150,
              render: (item) => item ?? '-',
            },
            { dataIndex: 'tr_item__item_name', title: 'Item', width: 150 },
            { dataIndex: 'tr_item__qty', title: 'PAX', width: 70 },
            {
              dataIndex: 'tr_item_bundling__total_net_price',
              title: 'Revenue',
              width: 150,
              render: (value) => currencyFormatter({ value }),
            },
          ]}
        />
      </Card>
    </AdminLayout>
  );
}
